Exec { timeout => 300 }

$amqp = 'rabbitmq'
case $amqp  {
  'qpid': {
    enable_qpid {"qpid":
      enable_ssl  => false,
      enable_auth => 'n',
    }
  }
  'rabbitmq': {
    enable_rabbitmq {"rabbitmq":}

  }
}


define enable_rabbitmq {
  package { "erlang":
    ensure => "installed"
  }

  class {"rabbitmq":
    port             => '5672',
    ssl_management_port      => '5671',
    ssl              => false,
    ssl_cert         => '',
    ssl_key          => '',
    default_user     => 'guest',
    default_pass     => 'guest',
    package_provider => 'yum',
    admin_enable     => false,
  }

  Package['erlang']->Class['rabbitmq']
}

define enable_qpid($enable_ssl = 'n', $enable_auth = 'n') {
  case $::operatingsystem {
    'Fedora': {
      if (is_integer($::operatingsystemrelease) and $::operatingsystemrelease >= 20) or $::operatingsystemrelease == "Rawhide" {
        $config = '/etc/qpid/qpidd.conf'
      } else {
        $config = '/etc/qpidd.conf'
      }
    }

    'RedHat', 'CentOS', 'Scientific': {
      if $::operatingsystemmajrelease >= 7 {
        $config = '/etc/qpid/qpidd.conf'
      } else {
        $config = '/etc/qpidd.conf'
      }
    }

    default: {
      $config = '/etc/qpidd.conf'
    }
  }

  class {"qpid::server":
    config_file => $config,
    auth => $enable_auth ? {
	    'y'  => 'yes',
	    default => 'no',
	    },
    clustered => false,
	    ssl_port      => '5671',
	    ssl           => false,
	    ssl_cert      => '',
	    ssl_key       => '',
	    ssl_database_password => '',
  }

  if $enable_ssl {
    # If there is qpid-cpp-server-ssl install it
    exec { 'install_qpid_ssl':
      path    => '/usr/bin',
      command => 'yum install -y -d 0 -e 0  qpid-cpp-server-ssl',
      onlyif  => 'yum info qpid-cpp-server-ssl',
      before  => Service['qpidd'],
      require => Package['qpid-cpp-server'],
    }
  }

  if $enable_auth == 'y' {
    add_qpid_user {"qpid_user":}
  }

}

define add_qpid_user {
  qpid_user { 'guest':
    password  => 'guest',
    file      => '/var/lib/qpidd/qpidd.sasldb',
    realm     => 'QPID',
    provider  => 'saslpasswd2',
    require   => Class['qpid::server'],
  }

  file { 'sasldb_file':
    path => '/var/lib/qpidd/qpidd.sasldb',
    ensure => file,
    owner => 'qpidd',
    group => 'qpidd',
    require => Package['qpid-cpp-server'],
  }
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'amqp_10.35.7.29':
  host => '10.35.7.29',
  service_name => 'amqp',
  chain => 'INPUT',
  ports => ['5671', '5672'],
  proto => 'tcp',
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'amqp_10.35.7.113':
  host => '10.35.7.113',
  service_name => 'amqp',
  chain => 'INPUT',
  ports => ['5671', '5672'],
  proto => 'tcp',
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'amqp_10.35.7.34':
  host => '10.35.7.34',
  service_name => 'amqp',
  chain => 'INPUT',
  ports => ['5671', '5672'],
  proto => 'tcp',
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'amqp_10.35.7.201':
  host => '10.35.7.201',
  service_name => 'amqp',
  chain => 'INPUT',
  ports => ['5671', '5672'],
  proto => 'tcp',
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'amqp_10.35.7.30':
  host => '10.35.7.30',
  service_name => 'amqp',
  chain => 'INPUT',
  ports => ['5671', '5672'],
  proto => 'tcp',
}
