Exec { timeout => 300 }


package { 'curl': ensure => present }

class { 'memcached':
}

class { 'swift::proxy':
  proxy_local_net_ip => '10.35.7.201',
  pipeline           => [
    'catch_errors',
    'bulk',
    'healthcheck',
    'cache',
    'crossdomain',
    'ratelimit',
    'authtoken',
    'keystone',
    'staticweb',
    'tempurl',
    'slo',
    'formpost',
    'account_quotas',
    'container_quotas',
    'proxy-server'
  ],
  account_autocreate => true,
}

# configure all of the middlewares
class { [
    'swift::proxy::catch_errors',
    'swift::proxy::healthcheck',
    'swift::proxy::cache',
    'swift::proxy::crossdomain',
    'swift::proxy::staticweb',
    'swift::proxy::tempurl',
    'swift::proxy::account_quotas',
    'swift::proxy::formpost',
    'swift::proxy::slo',
    'swift::proxy::container_quotas'
]: }

class { 'swift::proxy::bulk':
  max_containers_per_extraction => 10000,
  max_failed_extractions        => 1000,
  max_deletes_per_request       => 10000,
  yield_frequency               => 60,
}

class { 'swift::proxy::ratelimit':
    clock_accuracy         => 1000,
    max_sleep_time_seconds => 60,
    log_sleep_time_seconds => 0,
    rate_buffer_seconds    => 5,
    account_ratelimit      => 0
}

class { 'swift::proxy::keystone':
    operator_roles => ['admin', 'SwiftOperator'],
}

class { 'swift::proxy::authtoken':
    admin_user        => 'swift',
    admin_tenant_name => 'services',
    admin_password    => 'c70b27b723ce4d0b',
    # assume that the controller host is the swift api server
    auth_host         => '10.35.7.201',
}

# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'swift_proxy':
  host => 'ALL',
  service_name => 'swift proxy',
  chain => 'INPUT',
  ports => '8080',
  proto => 'tcp',
}


# install all swift storage servers together
class { 'swift::storage::all':
  storage_local_net_ip => '10.35.7.201',
  allow_versions => true,
  require => Class['swift'],
}

if(!defined(File['/srv/node'])) {
  file { '/srv/node':
    owner  => 'swift',
    group  => 'swift',
    ensure => directory,
    require => Package['openstack-swift'],
  }
}

swift::ringsync{ ["account", "container", "object"]:
    ring_server => '10.35.7.201',
    before => Class['swift::storage::all'],
    require => Class['swift'],
}


swift::storage::loopback { 'swift_loopback':
  base_dir     => '/srv/loopback-device',
  mnt_base_dir => '/srv/node',
  require      => Class['swift'],
  fstype       => 'ext4',
  seek         => '2097152',
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'swift_storage_and_rsync_10.35.7.34':
  host => '10.35.7.34',
  service_name => 'swift storage and rsync',
  chain => 'INPUT',
  ports => ['6000', '6001', '6002', '873'],
  proto => 'tcp',
}
# Create firewall rules to allow only the FIREWALL_ALLOWED
# hosts that need to connect via FIREWALL_PORTS
# using FIREWALL_CHAIN

packstack::firewall {'swift_storage_and_rsync_10.35.7.201':
  host => '10.35.7.201',
  service_name => 'swift storage and rsync',
  chain => 'INPUT',
  ports => ['6000', '6001', '6002', '873'],
  proto => 'tcp',
}


class { 'ssh::server::install': }

Class['swift'] -> Service <| |>
class { 'swift':
    # not sure how I want to deal with this shared secret
    swift_hash_suffix => '2187f4c18a4643c1',
    package_ensure    => latest,
}
